Learn R Programming

ggseg (version 1.6.8)

brain_labels: Extract unique labels of brain regions

Description

Convenience function to extract names of brain labels from a brain_atlas. Brain labels are usually default naming obtained from the original atlas data.

Usage

brain_labels(x)

# S3 method for ggseg_atlas brain_labels(x)

# S3 method for brain_atlas brain_labels(x)

Value

Character vector of atlas region labels

Arguments

x

brain atlas