Learn R Programming

ggseg (version 1.6.8)

read_atlas_files: Read in atlas data from all subjects

Description

Recursively reads in all stats files for an atlas (given a unique character string), for all subjects in the subjects directory. Will add hemisphere and subject id to the data.

Usage

read_atlas_files(subjects_dir, atlas)

Value

tibble with stats information for subjects from FreeSurfer

Arguments

subjects_dir

FreeSurfer subject directory

atlas

unique character combination identifying the atlas

Examples

Run this code
if (FALSE) {
subj_dir <- "/path/to/freesurfer/7.2.0/subjects/"
read_atlas_files(subj_dir, "aseg.stats")

read_atlas_files(subj_dir, "lh.aparc.stats")
}

Run the code above in your browser using DataLab