powered by
call to geom_sf
geom_sf
geom_brain( mapping = aes(), data = NULL, atlas, hemi = NULL, side = NULL, position = position_brain(), show.legend = NA, inherit.aes = TRUE, ... )
ggplot object
argument to pass to aes to map variables from the supplied data to the plot
aes
data.frame with data to plot
object of type brain_atlas to plot
hemisphere to plot. Defaults to everything in the atlas.
slice to plot, as recorded in the "side" column in the atlas data. Defaults to all.
position of the data. Default is "identity" but can be changed by position_brain.
position_brain
logical. Should legend be added or not.
logical. if aes should be inherited from the main ggplot call or not
arguments to geom_sf
library(ggplot2) ggplot() + geom_brain(atlas = dk)
Run the code above in your browser using DataLab