Function for repositioning pre-joined atlas data (i.e. data and atlas already joined to a single data frame). This makes it possible for users to reposition the geometry data for the atlas for control over final plot layout. For even more detailed control over the positioning, the "hemi" and "view" columns should be converted into factors and ordered by wanted order of appearance.
Arguments
- data
sf-data.frame of joined brain atlas and data
- position
Position formula for slices. For cortical atlases, use formulas like `hemi ~ view`. For subcortical/tract atlases, use "horizontal", "vertical", or `type ~ .` for type-based layout.
- nrow
Number of rows for grid layout (subcortical/tract only)
- ncol
Number of columns for grid layout (subcortical/tract only)
- views
Character vector specifying view order (subcortical/tract only)