Learn R Programming

ggseg (version 1.6.8)

reposition_brain: Reposition brain slices

Description

Function for repositioning pre-joined atlas data (i.e. data and atlas already joined to a single data frame). This makes it possible for users to reposition the geometry data for the atlas for control over final plot layout. For even more detailed control over the positioning, the "hemi" and "side" columns should be converted into factors and ordered by wanted order of appearance.

Usage

reposition_brain(data, position = "horizontal")

Value

sf-data.frame with repositioned slices

Arguments

data

sf-data.frame of joined brain atlas and data

position

position formula for slices

Examples

Run this code
reposition_brain(dk, hemi ~ side)
reposition_brain(dk, side ~ hemi)
reposition_brain(dk, hemi + side ~ .)
reposition_brain(dk, . ~ hemi + side)

Run the code above in your browser using DataLab