scale_continous_brain: Axis and label scales for brain atlas plots

View source: R/scale-brain.R

scale_continous_brainR Documentation

Axis and label scales for brain atlas plots

Description

Add axis labels and tick labels corresponding to brain atlas regions. These scales add hemisphere or view labels to the x and y axes based on the atlas layout.

Usage

scale_continous_brain(
  atlas = dk(),
  position = "dispersed",
  aesthetics = c("y", "x")
)

scale_x_brain(...)

scale_y_brain(...)

scale_labs_brain(atlas = dk(), position = "dispersed", aesthetics = "labs")

Arguments

atlas

A 'ggseg_atlas' object or data.frame containing atlas data.

position

Layout style: '"dispersed"' (default) or '"stacked"'.

aesthetics

Which axis to scale: '"x"', '"y"', or '"labs"'.

...

Additional arguments passed to [adapt_scales()].

Value

A ggplot2 scale or labs object.

Examples


library(ggplot2)

ggplot() +
  geom_brain(atlas = dk()) +
  scale_x_brain() +
  scale_y_brain() +
  scale_labs_brain()



ggseg documentation built on April 3, 2026, 5:06 p.m.