Learn R Programming

ggseg (version 1.6.7)

scale_continous_brain: Axis and label scales from the ggseg atlases

Description

The `brain` axis and label scales provides scales for the different atlases in the package. These add axis labels and tick labels corresponding to the different atlases.

Usage

scale_continous_brain(
  atlas = dk,
  position = "dispersed",
  aesthetics = c("y", "x")
)

scale_x_brain(...)

scale_y_brain(...)

scale_labs_brain(atlas = dk, position = "dispersed", aesthetics = "labs")

Value

a scaling function to alter continuous axes labels in ggplot2

Arguments

atlas

data.frame containing the atlas

position

Character of either "dispersed" or "stacked".

aesthetics

String vector of which aesthetics to scale "x", "y", or "labs".

...

additional arguments to pass to adapt_scales

Examples

Run this code
if (FALSE) {
scale_x_brain()
scale_y_brain()
scale_labs_brain()
}

Run the code above in your browser using DataLab